<?php
namespace XLite\Controller\Customer;
/**
 * \XLite\Controller\Customer\Cart
 */
class Cart extends \XLite\Module\Amazon\PayWithAmazon\Controller\Customer\Cart {}